==> flulm_auth-1.1.0.tar.gz: lib/src/aes/awesome_aes_encryption.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:encrypt/encrypt.dart';
import 'package:crypto/crypto.dart';

import 'package:convert/convert.dart';
import 'package:flutter/cupertino.dart' as p;

class AwesomeAesEncryption {

  static final String ENCRYPT_KEY_LOC_ANDROID = "17d6ce94c37e727848159b1e889493ca";
  static final String ENCRYPT_KEY_RC_ANDROID = "31f90da4142bbad7f93f702823e43a96";
  static final String ENCRYPT_KEY_RELEASE_ANDROID = "RxkILvb-NpSw1hDln6zzOpYb7xwLK5kDWK6eN536SkD7ig8uX38qkGo45bDxOB5C";

  static final String ENCRYPT_KEY_LOC_IOS = "1f17a97dec7ac0010dfe2589f829692c";
  static final String ENCRYPT_KEY_RC_IOS = "a13d5dc065b4f140009bba4ec627e348";
  static final String ENCRYPT_KEY_RELEASE_IOS = "7YmUUSMot22AcKZbeny4MuVWWKTgGcqktlb1PtGUudpOLct7rIW_ix7CJkLGdua2";

  //Base64编码
  static String encodeBase64(String data) {
    return base64Encode(utf8.encode(data));
  }

  //Base64解码
  static String decodeBase64(String data) {
    return String.fromCharCodes(base64Decode(data));
  }

  // md5 加密 32位小写
  static String encodeMd5(String plainText) {
    var content = Utf8Encoder().convert(plainText);
    var digest = md5.convert(content);
    return hex.encode(digest.bytes);
  }

  //AES加密
  static aesEncrypt(String encryptKey,String aesIv, String plainText) {
    try {
      final key = Key.fromUtf8(encryptKey);
      final iv = IV.fromUtf8(aesIv);
      final encrypter = Encrypter(AES(key, mode: AESMode.cbc));
      final encrypted = encrypter.encrypt(plainText, iv: iv);
      String base64 = encrypted.base64;
      base64 = base64.replaceAll("+", "-").replaceAll("/", "_").replaceAll("=", "");
      return base64;
    } catch (err) {
      print("aes encode error:$err");
      return plainText;
    }
  }

  //AES解密
  static dynamic aesDecrypt(String encryptKey,String aesIv,String encrypted) {
    try {
      encrypted = encrypted.replaceAll("[\\x00-\\x1F\\x80-\\x9F]", "");
      encrypted = encrypted.replaceAll("-", "+").replaceAll("_", "/");
      int mod4 = encrypted.length % 4;
      print("===mod4==" + mod4.toString());
      if (mod4 != 0) {
        encrypted += "====".substring(0, 4 - mod4);
      }
      final key = Key.fromUtf8(encryptKey);
      final iv = IV.fromUtf8(aesIv);
      final encrypter = Encrypter(AES(key, mode: AESMode.cbc,padding: null));
      final decrypted = encrypter.decrypt64(encrypted, iv: iv);
      return pkcs7UnPadding(decrypted);
    } catch (err) {
      p.debugPrint("aes decode error:$err");
      return encrypted;
    }
  }

  static String pkcs7UnPadding(String data) {
//     获取最后一个字符，其实就是补码那个字符，计算它的ASCII码，其实就是补码的长度
    var codeUnits = data.codeUnits;
    var padding = codeUnits[data.length - 1];
    print( "计算是否去除 补码 padding=" + padding.toString());

    if (padding > data.length) {
      // 补码的长度比字符串长度还长，说明没有补码，直接返回字符串
      return data.trim();
    }
    // 截取补码长度个字符，检查这个字符是否在这个区间出现的次数跟它的数值相等
    StringBuffer paddingBuilder = new StringBuffer();
    for (int i = 0; i < padding; i++) {
      paddingBuilder.write(String.fromCharCode(padding));
    }
    if (data.substring(data.length - padding) != (paddingBuilder.toString())) {
      return data.trim();
    }
    print("去除补码 padding=" + padding.toString());

    // 去掉补码，返回数据
    return data.substring(0, data.length - padding).trim();

  }

  static String dataEncrypt(String keyIv,String data){
    var encryptKey = keyIv.substring(0, 16);
    var aesIv = keyIv.substring(16, 32);
    var enStr = AwesomeAesEncryption.aesEncrypt(encryptKey,aesIv,data);
    p.debugPrint("keyIv = "+keyIv);
    p.debugPrint("encryptKey = "+encryptKey);
    p.debugPrint("aesIv = "+aesIv);
    p.debugPrint("加密后的数据 = "+enStr);
    return enStr;
  }

  static String getEncryptKey(int test) {
    //0正式 1外网测试 2测试
    if(Platform.isIOS){
      if (test == 1) {
        return ENCRYPT_KEY_RC_IOS;
      } else if (test == 2) {
        return ENCRYPT_KEY_LOC_IOS;
      }
      return AwesomeAesEncryption.aesDecrypt(ENCRYPT_KEY_LOC_ANDROID.substring(0,16),ENCRYPT_KEY_LOC_ANDROID.substring(16,32), ENCRYPT_KEY_RELEASE_IOS);

    }else{

      if (test == 1) {
        return ENCRYPT_KEY_RC_ANDROID;
      } else if (test == 2) {
        return ENCRYPT_KEY_LOC_ANDROID;
      }
      return AwesomeAesEncryption.aesDecrypt(ENCRYPT_KEY_LOC_ANDROID.substring(0,16),ENCRYPT_KEY_LOC_ANDROID.substring(16,32), ENCRYPT_KEY_RELEASE_ANDROID);

    }
   }

  static String getSDKApi(int  isTest){
    String host;
    switch (isTest) {
      case 1:
        host = "https://testsdkapi.lmpayplc.com";
        break;
      case 2:
        host = "http://sdkapi1.lmpayplc.com";
        break;
      case 0:
      default:
        host = "https://sdkapi.lmpayplc.com";
    }
    return host;
  }

  String getH5WebDataHost(int isTest) {
    return getSDKApi(isTest) + "?ct=web&ac=get_web_data";
  }

  static Options getOptions({String csrf}) {
    return new Options(
      contentType: "application/x-www-form-urlencoded",
      headers: csrf != null ?{"csrf":csrf,"ENCRYPT":csrf!=null? "1" : null,"os":Platform.isIOS?"ios":Platform.isAndroid?"android":""}:Map(),
      responseType: csrf != null ? ResponseType.plain:ResponseType.json,
      method: "post",
    );
  }

}

==> flulm_auth-2.1.0.tar.gz: lib/src/aes/awesome_aes_encryption.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:encrypt/encrypt.dart';
import 'package:crypto/crypto.dart';

import 'package:convert/convert.dart';
import 'package:flutter/cupertino.dart' as p;

class AwesomeAesEncryption {

  static final String ENCRYPT_KEY_LOC_ANDROID = "17d6ce94c37e727848159b1e889493ca";
  static final String ENCRYPT_KEY_RC_ANDROID = "31f90da4142bbad7f93f702823e43a96";
  static final String ENCRYPT_KEY_RELEASE_ANDROID = "RxkILvb-NpSw1hDln6zzOpYb7xwLK5kDWK6eN536SkD7ig8uX38qkGo45bDxOB5C";

  static final String ENCRYPT_KEY_LOC_IOS = "1f17a97dec7ac0010dfe2589f829692c";
  static final String ENCRYPT_KEY_RC_IOS = "a13d5dc065b4f140009bba4ec627e348";
  static final String ENCRYPT_KEY_RELEASE_IOS = "7YmUUSMot22AcKZbeny4MuVWWKTgGcqktlb1PtGUudpOLct7rIW_ix7CJkLGdua2";

  //Base64编码
  static String encodeBase64(String data) {
    return base64Encode(utf8.encode(data));
  }

  //Base64解码
  static String decodeBase64(String data) {
    return String.fromCharCodes(base64Decode(data));
  }

  // md5 加密 32位小写
  static String encodeMd5(String plainText) {
    var content = Utf8Encoder().convert(plainText);
    var digest = md5.convert(content);
    return hex.encode(digest.bytes);
  }

  //AES加密
  static aesEncrypt(String encryptKey,String aesIv, String plainText) {
    try {
      final key = Key.fromUtf8(encryptKey);
      final iv = IV.fromUtf8(aesIv);
      final encrypter = Encrypter(AES(key, mode: AESMode.cbc));
      final encrypted = encrypter.encrypt(plainText, iv: iv);
      String base64 = encrypted.base64;
      base64 = base64.replaceAll("+", "-").replaceAll("/", "_").replaceAll("=", "");
      return base64;
    } catch (err) {
      print("aes encode error:$err");
      return plainText;
    }
  }

  //AES解密
  static dynamic aesDecrypt(String encryptKey,String aesIv,String encrypted) {
    try {
      encrypted = encrypted.replaceAll("[\\x00-\\x1F\\x80-\\x9F]", "");
      encrypted = encrypted.replaceAll("-", "+").replaceAll("_", "/");
      int mod4 = encrypted.length % 4;
      print("===mod4==" + mod4.toString());
      if (mod4 != 0) {
        encrypted += "====".substring(0, 4 - mod4);
      }
      final key = Key.fromUtf8(encryptKey);
      final iv = IV.fromUtf8(aesIv);
      final encrypter = Encrypter(AES(key, mode: AESMode.cbc,padding: null));
      final decrypted = encrypter.decrypt64(encrypted, iv: iv);
      return pkcs7UnPadding(decrypted);
    } catch (err) {
      p.debugPrint("aes decode error:$err");
      return encrypted;
    }
  }

  static String pkcs7UnPadding(String data) {
//     获取最后一个字符，其实就是补码那个字符，计算它的ASCII码，其实就是补码的长度
    var codeUnits = data.codeUnits;
    var padding = codeUnits[data.length - 1];
    print( "计算是否去除 补码 padding=" + padding.toString());

    if (padding > data.length) {
      // 补码的长度比字符串长度还长，说明没有补码，直接返回字符串
      return data.trim();
    }
    // 截取补码长度个字符，检查这个字符是否在这个区间出现的次数跟它的数值相等
    StringBuffer paddingBuilder = new StringBuffer();
    for (int i = 0; i < padding; i++) {
      paddingBuilder.write(String.fromCharCode(padding));
    }
    if (data.substring(data.length - padding) != (paddingBuilder.toString())) {
      return data.trim();
    }
    print("去除补码 padding=" + padding.toString());

    // 去掉补码，返回数据
    return data.substring(0, data.length - padding).trim();

  }

  static String dataEncrypt(String keyIv,String data){
    var encryptKey = keyIv.substring(0, 16);
    var aesIv = keyIv.substring(16, 32);
    var enStr = AwesomeAesEncryption.aesEncrypt(encryptKey,aesIv,data);
    p.debugPrint("keyIv = "+keyIv);
    p.debugPrint("encryptKey = "+encryptKey);
    p.debugPrint("aesIv = "+aesIv);
    p.debugPrint("加密后的数据 = "+enStr);
    return enStr;
  }

  static String getEncryptKey(int? test) {
    //0正式 1外网测试 2测试
    if(Platform.isIOS){
      if (test == 1) {
        return ENCRYPT_KEY_RC_IOS;
      } else if (test == 2) {
        return ENCRYPT_KEY_LOC_IOS;
      }
      return AwesomeAesEncryption.aesDecrypt(ENCRYPT_KEY_LOC_ANDROID.substring(0,16),ENCRYPT_KEY_LOC_ANDROID.substring(16,32), ENCRYPT_KEY_RELEASE_IOS);

    }else{

      if (test == 1) {
        return ENCRYPT_KEY_RC_ANDROID;
      } else if (test == 2) {
        return ENCRYPT_KEY_LOC_ANDROID;
      }
      return AwesomeAesEncryption.aesDecrypt(ENCRYPT_KEY_LOC_ANDROID.substring(0,16),ENCRYPT_KEY_LOC_ANDROID.substring(16,32), ENCRYPT_KEY_RELEASE_ANDROID);

    }
   }

  static String getSDKApi(int?  isTest){
    String host;
    switch (isTest) {
      case 1:
        host = "https://testsdkapi.lmpayplc.com";
        break;
      case 2:
        host = "http://sdkapi1.lmpayplc.com";
        break;
      case 0:
      default:
        host = "https://sdkapi.lmpayplc.com";
    }
    return host;
  }

  String getH5WebDataHost(int isTest) {
    return getSDKApi(isTest) + "?ct=web&ac=get_web_data";
  }

  static Options getOptions({String? csrf}) {
    return new Options(
      contentType: "application/x-www-form-urlencoded",
      headers: csrf != null ?{"csrf":csrf,"ENCRYPT":csrf!=null? "1" : null,"os":Platform.isIOS?"ios":Platform.isAndroid?"android":""}:Map(),
      responseType: csrf != null ? ResponseType.plain:ResponseType.json,
      method: "post",
    );
  }

}
